@@ -4,7 +4,7 @@ from amazon_ad.api_v3.base import ZADOpenAPIV3
 from amazon_ad.api_v3.adapters import SBPurchasedProductReportsAdapter
 
 
-class SpReportV3(ZADOpenAPIV3):
+class SbReportV3(ZADOpenAPIV3):
 
     def request(self, data: dict):
         path = "/reporting/reports"
