@@ -15,6 +15,7 @@ from amazon_ad.api.sb.campaigns import SbCampaigns
 
 from amazon_ad.api_v3.report import ReportGetV3, ReportDownloadV3
 from amazon_ad.api_v3.sp.report import SpReportV3
+from amazon_ad.api_v3.sb.report import SbReportV3
 
 
 class ZADApiClient(BaseClient):
@@ -103,6 +104,7 @@ class ZADServiceClientV3(ZADApiClient):
     report_get = ReportGetV3()
     report_download = ReportDownloadV3()
     sp_report = SpReportV3()
+    sb_report = SbReportV3()
 
     def __init__(self, client_id,  access_token, profile_id, country="US", account_type='seller', prepare_mode=False, timeout=(30, 300), auto_retry=True, *args, **kwargs):
         region = get_region(country)
